==> haskell-topograph-1.0.0.2-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-IMTKb35MN2S4TcQeF7GDip
key:                  topograph-1.0.0.2-IMTKb35MN2S4TcQeF7GDip
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  0bfaa63846d94642321a0a2038f0b14a
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-IMTKb35MN2S4TcQeF7GDip
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    base-orphans-0.9.3-21Kg0ZpixBhIWAAM72mV1W containers-0.6.7
    vector-0.13.2.0-HGgKaKiJszd4ty04a0OkB8

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-topograph-1.0.0.2-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-IJUxBgotrj46gujWKSfGwh
key:                  topograph-1.0.0.2-IJUxBgotrj46gujWKSfGwh
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  35a9b2bb65cc907a074635d06e4706d4
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-IJUxBgotrj46gujWKSfGwh
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    base-orphans-0.9.3-5ChHjCRNHFNLSCQEOfBOb6 containers-0.6.7
    vector-0.13.2.0-o0y58FfPZzKSAM3ADJGlg

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
